clear all; close all; clc
addpath('apm')

%% numerical solution
y = apm_solve('co',4);
z = y.x;

%% exact solution
ns = 10;
% n * dy/dt = 1e6 * nco_in - n_out * y
% n/n_out * dy/dt = 1e6 * nco_in/n_out - y
% tau * dy/dt = -y + K * u
% tau = n/n_out
time = linspace(0,8*60,ns);
P = 1.01e5; 
T = 300;   
R = 8.314; 
V = 200 * 9 / ( 3.28 ^ 3 );
n = P * V / (R * T);
Vco_in = 6e-6;
nco_in = P * Vco_in / (R * T);
n_out = nco_in;
K = 1e6 * nco_in/n_out;
tau = n/n_out;
yco_exact(1:ns) = (1 - exp(-time(1:ns)/tau))*K;

figure(1)
plot(z.time/60,z.yco_twa,'r:','LineWidth',2)
hold on
plot(z.time/60,z.yco,'b:','LineWidth',2)
plot(time/60,yco_exact,'k.','LineWidth',2,'MarkerSize',8)
plot([0 8],[35 35],'g--','LineWidth',3)
plot([0 8],[200 200],'r-','LineWidth',3)
legend('CO TWA (ppm)','CO Numerical (ppm)','CO Analytic (ppm)','OSHA 8 Hr TWA','OSHA Max')
axis([0 8 0 205])
xlabel('Time (hr)')
ylabel('Concentration (ppm)')